IcmpEchoContextMarker

Trait IcmpEchoContextMarker 

pub trait IcmpEchoContextMarker { }
Resolve coherence issues by requiring a trait implementation with no type parameters, which makes the blanket implementations for the datagram specs viable.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors